@@ -76,21 +76,33 @@ module MiniMagick
     # @param path_or_url [String] Either a local file path or a URL that
     #   open-uri can read
     # @param ext [String] Specify the extension you want to read it as
+    # @param options [Hash] Specify options for the open method
     # @return [MiniMagick::Image] The loaded image
     #
-    def self.open(path_or_url, ext = nil)
-      ext ||=
-        if File.exist?(path_or_url)
-          File.extname(path_or_url)
+    def self.open(path_or_url, ext = nil, options = {})
+      options, ext = ext, nil if ext.is_a?(Hash)
+
+      # Don't use Kernel#open, but reuse its logic
+      openable =
+        if path_or_url.respond_to?(:open)
+          path_or_url
+        elsif path_or_url.respond_to?(:to_str) &&
+              %r{\A[A-Za-z][A-Za-z0-9+\-\.]*://} =~ path_or_url &&
+              (uri = URI.parse(path_or_url)).respond_to?(:open)
+          uri
         else
-          File.extname(URI(path_or_url).path)
+          options = { binmode: true }.merge(options)
+          Pathname(path_or_url)
         end
 
+      if openable.is_a?(URI::Generic)
+        ext ||= File.extname(openable.path)
+      else
+        ext ||= File.extname(openable.to_s)
+      end
       ext.sub!(/:.*/, '') # hack for filenames or URLs that include a colon
 
-      Kernel.open(path_or_url, "rb") do |file|
-        read(file, ext)
-      end
+      openable.open(options) { |file| read(file, ext) }
     end
 
     ##
@@ -343,11 +355,14 @@ module MiniMagick
     #
     # @return [Array] Matrix of each color of each pixel
     def get_pixels
-      output = MiniMagick::Tool::Convert.new do |convert|
-        convert << path
-        convert.depth(8)
-        convert << "RGB:-"
-      end
+      convert = MiniMagick::Tool::Convert.new
+      convert << path
+      convert.depth(8)
+      convert << "RGB:-"
+
+      # Do not use `convert.call` here. We need the whole binary (unstripped) output here.
+      shell = MiniMagick::Shell.new
+      output, * = shell.run(convert.command)
 
       pixels_array = output.unpack("C*")
       pixels = pixels_array.each_slice(3).each_slice(width).to_a
