@@ -68,6 +68,11 @@ require "webmock/rspec"
           expect(image).to be_valid
         end
 
+        it "accepts a non-ascii filename" do
+          image = described_class.open(image_path(:non_ascii_filename))
+          expect(image).to be_valid
+        end
+
         it "loads a remote image" do
           stub_request(:get, "http://example.com/image.jpg")
             .to_return(body: File.read(image_path))
@@ -76,12 +81,20 @@ require "webmock/rspec"
           expect(File.extname(image.path)).to eq ".jpg"
         end
 
+        it "doesn't allow remote shell execution" do
+          expect {
+            described_class.open("| touch file.txt") # Kernel#open accepts this
+          }.to raise_error(Errno::ENOENT)
+
+          expect(File.exist?("file.txt")).to eq(false)
+        end
+
         it "accepts open-uri options" do
           stub_request(:get, "http://example.com/image.jpg")
             .with(headers: {"Foo" => "Bar"})
             .to_return(body: File.read(image_path))
           described_class.open("http://example.com/image.jpg", {"Foo" => "Bar"})
-          described_class.open("http://example.com/image.jpg", "jpg", {"Foo" => "Bar"})
+          described_class.open("http://example.com/image.jpg", ".jpg", {"Foo" => "Bar"})
         end
 
         it "strips out colons from URL" do
@@ -386,15 +399,20 @@ require "webmock/rspec"
       end
 
       describe "#exif" do
-        subject { described_class.new(image_path(:exif)) }
-
         it "returns a hash of EXIF data" do
+          subject = described_class.new(image_path(:exif))
           expect(subject.exif["DateTimeOriginal"]).to be_a(String)
         end
 
         it "decodes the ExifVersion" do
+          subject = described_class.new(image_path(:exif))
           expect(subject.exif["ExifVersion"]).to eq("0220")
         end unless ENV["CI"]
+
+        it "handles no EXIF data" do
+          subject = described_class.new(image_path(:no_exif))
+          expect(subject.exif).to eq({})
+        end
       end
 
       describe "#resolution" do
@@ -415,7 +433,12 @@ require "webmock/rspec"
         it "returns a hash of verbose information" do
           expect(subject.details["Format"]).to match /^JPEG/
           if MiniMagick.cli == :imagemagick
-            expect(subject.details["Channel depth"]["Red"]).to eq "8-bit"
+            if Gem::Version.new(MiniMagick.cli_version) < Gem::Version.new('7.0.0')
+              expect(subject.details["Channel depth"]["red"]).to eq "8-bit"
+            else
+              expect(subject.details["Channel depth"]["Red"]).to eq "8-bit"
+            end
+
             expect(subject.details).to have_key("Background color")
             expect(subject.details["Properties"]).to have_key("date:create")
           else
