@@ -1,3 +1,5 @@
+# encoding: utf-8
+
 require "tempfile"
 
 module Helpers
@@ -9,6 +11,7 @@ module Helpers
         when :png                 then "engine.png"
         when :animation, :gif     then "animation.gif"
         when :exif                then "exif.jpg"
+        when :no_exif             then "no_exif.jpg"
         when :empty_identify_line then "empty_identify_line.png"
         when :badly_encoded_line  then "badly_encoded_line.jpg"
         when :not                 then "not_an_image.rb"
@@ -17,6 +20,7 @@ module Helpers
         when :get_pixels          then "get_pixels.png"
         when :rgb                 then "rgb.png"
         when :rgb_tmp             then "rgb_tmp.png"
+        when :non_ascii_filename  then "スクリーンショット 2019-07-13 1.32.01.png"
         else
           fail "image #{type.inspect} doesn't exist"
         end
